pub struct AccessLogEntry {
pub method: String,
pub path: String,
pub timestamp_ms: u64,
}Expand description
Access log entry written to the Bus by AccessLogGuard.
Downstream nodes can read this to inspect what was logged.
Fields
method: Stringpath: Stringtimestamp_ms: u64Trait Implementations
Sourceimpl Clone for AccessLogEntry
impl Clone for AccessLogEntry
Sourcefn clone(&self) -> AccessLogEntry
fn clone(&self) -> AccessLogEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccessLogEntry
impl Debug for AccessLogEntry
Sourceimpl<'de> Deserialize<'de> for AccessLogEntry
impl<'de> Deserialize<'de> for AccessLogEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more